import { Injectable } from '@nestjs/common';
import { CreateAuthDto } from './dto/create-auth.dto';
import { AuthEntity } from './entities/auth.entity';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { JwtService } from '@nestjs/jwt';
import * as bcryptjs from 'bcryptjs';

@Injectable()
export class AuthService {
  constructor(
    @InjectRepository(AuthEntity) private readonly user: Repository<AuthEntity>,
    private readonly jwtService: JwtService,
  ) {}

  async signup(signupData: CreateAuthDto) {
    const findUser = await this.user.findOne({
      where: { username: signupData.username },
    });

    if (findUser && findUser.username === signupData.username)
      return '用户已注册';
    signupData.password = bcryptjs.hashSync(signupData.password, 10);
    this.user.save(signupData);
    return '注册成功';
  }

  async login(loginData: CreateAuthDto) {
    const findUser = await this.user.findOne({
      where: { username: loginData.username },
    });

    if (!findUser) return '用户不存在';

    const compareRes: boolean = bcryptjs.compareSync(
      loginData.password,
      findUser.password,
    );

    if (!compareRes) return { msg: '账号或者密码不正确' };
    const payload = { id: findUser.id, username: findUser.username };

    return {
      token: this.jwtService.sign(payload),
      msg: '登录成功',
    };
  }

  async getUserInfo(userId: number) {
    const { password, ...result } = await this.user.findOne({
      where: { id: userId },
    });
    return result;
  }
}
