import {
  ExceptionFilter,
  Catch,
  ArgumentsHost,
  HttpException,
  HttpStatus,
} from '@nestjs/common';
import { Response } from 'express';

@Catch(HttpException)
export class HttpExceptionFilter implements ExceptionFilter {
  catch(exception: HttpException, host: ArgumentsHost) {
    const ctx = host.switchToHttp();
    const response = ctx.getResponse<Response>();
    const status = exception.getStatus
      ? exception.getStatus()
      : HttpStatus.INTERNAL_SERVER_ERROR;
    const exceptionResponse = exception.getResponse() as { message };
    const errorMessage = exceptionResponse.message
      ? exceptionResponse.message
      : exception.message;
    response.status(status).json({
      code: status,
      message: Array.isArray(errorMessage)
        ? errorMessage.join(',')
        : errorMessage,
      data: null,
    });
  }
}
