import * as OSS from 'ali-oss';
import { Injectable } from '@nestjs/common';
import * as dayjs from 'dayjs';
import { ConfigService } from '@nestjs/config';

@Injectable()
export class OssService {
  constructor(private configService: ConfigService) {}
  async getSignature() {
    const ossConfig = this.configService.get('oss');
    const config = {
      // 填写你自己的 AccessKey
      accessKeyId: ossConfig.accessKeyId,
      accessKeySecret: ossConfig.accessKeySecret, // 存储桶名字
      bucket: ossConfig.bucket, // 文件存储路径
      dir: ossConfig.dir,
    };
    const client = new OSS(config);
    const date = new Date(); // 时长加 1 天，作为签名的有限期
    date.setDate(date.getDate() + 1);
    const policy = {
      // 设置签名的有效期，格式为Unix时间戳
      expiration: date.toISOString(),
      conditions: [
        ['content-length-range', 0, 10485760000], // 设置上传文件的大小限制
      ],
    }; // 生成签名，策略等信息
    const formData = await client.calculatePostSignature(policy); // 生成 bucket 域名，客户端将向此地址发送请求
    const location = await client.getBucketLocation(ossConfig.bucket);
    const host = `https://${config.bucket}.${location.location}.aliyuncs.com`; // 响应给客户端的签名和策略等信息
    return {
      expire: dayjs().add(1, 'days').unix().toString(),
      policy: formData.policy,
      signature: formData.Signature,
      accessId: formData.OSSAccessKeyId,
      host,
      dir: config.dir,
    };
  }
}
