import { Injectable, NotFoundException } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';

import { Repository } from 'typeorm';
import { UserEntity } from './entities/user.entity';
import { CreateUserDto } from './dto/create-user.dto';
import { UpdateUserDto } from './dto/update-user.dto';

@Injectable()
export class UserService {
  constructor(
    @InjectRepository(UserEntity)
    private readonly userRepository: Repository<UserEntity>,
  ) {}
  async create(createUserDto: CreateUserDto): Promise<UserEntity> {
    const newUser = await this.userRepository.create(createUserDto);
    await this.userRepository.save(newUser);
    return newUser;
  }

  async login(user: any) {
    return {
      status: 'ok',
      ...user,
    };
  }

  findAll() {
    return this.userRepository.find();
  }

  async findOne(id: number) {
    const userInfo = await this.userRepository.findOne({
      where: { id },
    });
    return userInfo;
  }

  async update(id: number, updateUserDto: UpdateUserDto) {
    const oldData = await this.userRepository.findOne({
      where: {
        id,
      },
    });
    const mergedData = this.userRepository.merge(oldData, updateUserDto);
    return await this.userRepository.save(mergedData);
  }

  async remove(id: number) {
    const result = await this.userRepository.delete(id);
    if (result.affected === 0) {
      throw new NotFoundException(`User with ID ${id} not found`);
    }
    return result;
  }
}
